<?php
/**
* History:
*
* 1.0.0 - First version
* 1.1.0 - display informations of the TPL (file and template)
* 1.1.1 - add "*" for select all address IP
* 1.2.0 - add CSS and JS for each modules
* 1.2.1 - optimization display
* 1.2.2 - optimization display (icon)
* 1.2.3 - open block H-M by hover or click
* 1.2.4 - add Module::isEnabled in overrides
* 1.2.5 - displaying the full url of the template
* 1.2.6 - modification of CSS for display "+", this "+" will not be displayed with the themes that have not bootstrap)
* 1.2.7 - option "front office only" and option "all the time" for display all datas without click
* 1.2.8 - small patch
* 1.3.0 - option display/hide informations with the touch ²
* 1.3.1 - the key ² was not recognized on firefox, problem corrected
* 1.4.0 - compatible prestashop 1.7 RC3
* 1.4.1 - compatible prestashop 1.7.1
* 1.5.0 - update back office configuration
* 1.6.0 - BO available on ps 1.7
*
*  @author    Vincent MASSON <contact@coeos.pro>
*  @copyright Vincent MASSON <www.coeos.pro>
*  @license   http://www.coeos.pro/fr/content/3-conditions-generales-de-ventes
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

class WhatIsThisModule extends Module
{
    protected $error = false;

    public function __construct()
    {
        $this->name = 'whatisthismodule';
        $this->tab = 'administration';
        $this->version = '1.6.0';
        $this->author = 'www.coeos.pro';
        $this->come_from = 'coeos.pro';
        $this->need_instance = 0;
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('What is this module ?');
        $this->description = $this->l('Displays informations about hooks, modules, CSS and JS files.');
        $this->confirmUninstall = $this->l('Are you sure you want to delete this module ?');
    }
    public function install()
    {
        return (parent::install()
            && Configuration::updateValue('witm_config', '')
            && Configuration::updateValue('witm_css_js', 1)
            && Configuration::updateValue('witm_h_m', 1)
            && Configuration::updateValue('witm_fo', 1)
            && $this->registerHook('header'));
    }
    public function uninstall()
    {
        return (parent::uninstall()
            && Configuration::deleteByName('witm_config')
            && Configuration::deleteByName('witm_css_js')
            && Configuration::deleteByName('witm_h_m')
            && Configuration::deleteByName('witm_fo')
            );
    }
    public function hookHeader()
    {
        if (defined('_PS_ADMIN_DIR_') && (int)Configuration::get('witm_fo') == 1) {
            return;
        }
        $this->context->controller->addCSS($this->_path.
            'views/css/'.$this->name.'_'.(int)Configuration::get('witm_h_m').'.css');
        if (Configuration::get('witm_h_m') != 3) {
            $this->context->controller->addJS($this->_path.'views/js/'.$this->name.'.js');
        }
        if (Configuration::get('witm_h_m') == 4) {
            $this->context->controller->addJS($this->_path.'views/js/'.$this->name.'_ctrl.js');
        }
    }
    public function getContent()
    {
        $this->_html = '';
        if (Tools::isSubmit('submitConfigAdd')) {
            if ($this->saveConfigWITM()) {
                $this->_html .= $this->displayConfirmation($this->l('The data has been added successfully'));
            } else {
                $this->_html .= $this->displayError($this->l('An error occured during saving'));
            }
        }
        $this->displayForm();
        return $this->_html;
    }
    private function saveConfigWITM()
    {
        $ip = Tools::getValue('ip');
        $css_js = (int)Tools::getValue('witm_css_js', 0);
        $h_m = (int)Tools::getValue('witm_h_m', 1);
        $witm_fo = (int)Tools::getValue('witm_fo', 0);
        Configuration::updateValue('witm_config', $ip);
        Configuration::updateValue('witm_css_js', $css_js);
        Configuration::updateValue('witm_h_m', $h_m);
        Configuration::updateValue('witm_fo', $witm_fo);
        return true;
    }
    private function displayForm()
    {

        $this->smarty->assign(array(
            'ps_version' => _PS_VERSION_,
            'come_from' => $this->come_from,
            'path' => $this->_path,
            'tpl_dir' => '',
            'iso_code' => $this->context->language->iso_code,
            'version' => $this->version,
            'displayName' => $this->displayName,
            'name' => $this->name,
            'module_name' => $this->displayName,
            'witm_config' => Configuration::get('witm_config'),
            'witm_css_js' => Configuration::get('witm_css_js'),
            'witm_h_m' => Configuration::get('witm_h_m'),
            'witm_fo' => Configuration::get('witm_fo'),
            'ip' => Tools::getRemoteAddr(),
            'shop_name' => $this->context->shop->name));
        $this->_html .= $this->display(__FILE__, 'views/templates/admin/prestui/presentation.tpl');
        $this->_html .= $this->display(__FILE__, 'views/templates/admin/prestui/'.$this->name.'.tpl');
        $this->_html .= $this->display(__FILE__, 'views/templates/admin/prestui/ps-alert.tpl');
        $this->_html .= $this->display(__FILE__, 'views/templates/admin/prestui/ps-form.tpl');
        $this->_html .= $this->display(__FILE__, 'views/templates/admin/prestui/ps-panel.tpl');
        $this->_html .= $this->display(__FILE__, 'views/templates/admin/prestui/ps-table.tpl');
        $this->_html .= $this->display(__FILE__, 'views/templates/admin/prestui/ps-tabs.tpl');
        $this->_html .= $this->display(__FILE__, 'views/templates/admin/prestui/ps-tags.tpl');
        $this->context->controller->addJS(($this->_path).'views/js/riot.min.js');
        $this->context->controller->addJS(($this->_path).'views/js/riot_compiler.min.js');
        $this->context->controller->addCSS(($this->_path).'views/css/'.$this->name.'.css');
    }
}
